export enum Provider {
  Local = 'local',
  Openid = 'openid',
  SAML = 'saml',
  WebSSO = 'web-sso'
}
